import {
  Body,
  Container,
  Head,
  Heading,
  Html,
  Preview,
  Tailwind,
  Column,
  Row,
  Section,
  Text,
  Img,
} from '@react-email/components';
import type { z } from 'zod';

import { env } from '~/env';

import type { FormSchema } from '../schemas';

const FormEmail = ({
  data,
  imagePath,
}: {
  data: z.infer<typeof FormSchema>;
  imagePath?: string;
}) => {
  return (
    <Html>
      <Preview>Nuovo Modulo Inviato</Preview>
      <Tailwind>
        <Head />
        <Body className='bg-gray-100 font-sans'>
          <Section>
            <Container className='mx-auto max-w-xl rounded-lg bg-white p-6 shadow-md'>
              <Heading className='text-2xl font-bold text-gray-800'>Nuovo Modulo Inviato</Heading>
              <Text className='mt-2 text-gray-600'>{new Date().toLocaleDateString('en-GB')}</Text>
            </Container>
          </Section>
          <Section className='my-6 rounded-lg border border-gray-300 bg-white p-4 md:p-6'>
            <Row className='space-y-4'>
              {[
                { label: 'Nome', value: data.nome },
                { label: 'Anni', value: data.anni },
                { label: 'Email', value: data.email },
                { label: 'Telefono', value: data.telefono },
                { label: 'Contattato', value: data.contattato.join(', ') },
                { label: 'Parodontite', value: data.parodontite },
                { label: 'Dentista Visita Italia', value: data.dentistaVisitaItalia },
                { label: 'Panoramica', value: data.panaromicaDentale },
                { label: 'Tua Domanda', value: data.tuaDomanda },
              ].map(({ label, value }) => (
                <Column key={label} className='flex flex-row gap-x-2'>
                  <Text className='mb-0 mr-4 whitespace-nowrap font-semibold text-gray-700'>
                    {label}:
                  </Text>
                  <Text className='mr-4 text-gray-800'>{value}</Text>
                </Column>
              ))}

              {data.panaromicaDentale === 'Si' && data.panoramica && imagePath ? (
                <Column className='flex flex-row gap-x-2'>
                  <Img
                    src={`${env.NEXT_PUBLIC_APP_URL}/${imagePath}`}
                    alt={data.nome}
                    height={500}
                    width={500}
                  />
                </Column>
              ) : null}
            </Row>
          </Section>
        </Body>
      </Tailwind>
    </Html>
  );
};

export default FormEmail;

FormEmail.PreviewProps = {
  data: {
    parodontite: 'Si',
    anni: '18-29',
    dentistaVisitaItalia: 'Si',
    panaromicaDentale: 'Si',
    nome: 'Client',
    email: 'test@mail.com',
    telefono: '+391234567',
    contattato: ['Whatsapp', 'Email'],
    panoramica: '/public/favicon.ico',
    tuaDomanda: 'This is a sample question.',
  },
  imagePath: '/favicon.ico',
};
